@@ -13,11 +13,11 @@ Text::Amuse - Generate HTML and LaTeX documents from Emacs Muse markup.
 
 =head1 VERSION
 
-Version 0.72
+Version 0.73
 
 =cut
 
-our $VERSION = '0.72';
+our $VERSION = '0.73';
 
 
 =head1 SYNOPSIS
@@ -449,22 +449,48 @@ Babel, Polyglossia, etc.
 sub _language_mapping {
     my $self = shift;
     return {
+            ar => 'arabic', # R2L, unsupported so far
+            bg => 'bulgarian',
+            ca => 'catalan',
             cs => 'czech',
+            da => 'danish',
             de => 'german',
+            el => 'greek',
             en => 'english',
             es => 'spanish',
+            et => 'estonian',
             fi => 'finnish',
             fr => 'french',
+            ga => 'irish',
+            gl => 'galician',
+            he => 'hebrew',  # R2L, unsupported so far
+            hi => 'hindi',
             hr => 'croatian',
+            hu => 'magyar',
+            is => 'icelandic',
             it => 'italian',
-            sr => 'serbian',
-            ru => 'russian',
+            lo => 'lao',
+            lv => 'latvian',
+            lt => 'lithuanian',
+            ml => 'malayalam',
+            mk => 'macedonian', # needs workaround
+            mr => 'marathi',
             nl => 'dutch',
-            pt => 'portuges',
-            tr => 'turkish',
-            mk => 'macedonian',
-            sv => 'swedish',
+            no => 'norsk',
+            nn => 'nynorsk',
+            oc => 'occitan',
+            sr => 'serbian',
+            ro => 'romanian',
+            ru => 'russian',
+            sk => 'slovak',
+            sl => 'slovenian',
             pl => 'polish',
+            pt => 'portuges',
+            sq => 'albanian',
+            sv => 'swedish',
+            tr => 'turkish',
+            uk => 'ukrainian',
+            vi => 'vietnamese',
            };
 }
 
